==> zio-aws-apigatewaymanagementapi_2.12-5.17.104.9-sources.jar: zio/aws/apigatewaymanagementapi/model/GetConnectionRequest.scala <==
package zio.aws.apigatewaymanagementapi.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.apigatewaymanagementapi.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetConnectionRequest(connectionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest = {
    import GetConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
      .builder()
      .connectionId(__string.unwrap(connectionId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewaymanagementapi.model.GetConnectionRequest.ReadOnly =
    zio.aws.apigatewaymanagementapi.model.GetConnectionRequest
      .wrap(buildAwsValue())
}
object GetConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewaymanagementapi.model.GetConnectionRequest =
      zio.aws.apigatewaymanagementapi.model.GetConnectionRequest(connectionId)
    def connectionId: __string
    def getConnectionId: ZIO[Any, Nothing, __string] = ZIO.succeed(connectionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
  ) extends zio.aws.apigatewaymanagementapi.model.GetConnectionRequest.ReadOnly {
    override val connectionId: __string =
      zio.aws.apigatewaymanagementapi.model.primitives
        .__string(impl.connectionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
  ): zio.aws.apigatewaymanagementapi.model.GetConnectionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewaymanagementapi_2.12-5.19.33.2-sources.jar: zio/aws/apigatewaymanagementapi/model/GetConnectionRequest.scala <==
package zio.aws.apigatewaymanagementapi.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.apigatewaymanagementapi.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetConnectionRequest(connectionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest = {
    import GetConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
      .builder()
      .connectionId(connectionId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewaymanagementapi.model.GetConnectionRequest.ReadOnly =
    zio.aws.apigatewaymanagementapi.model.GetConnectionRequest
      .wrap(buildAwsValue())
}
object GetConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewaymanagementapi.model.GetConnectionRequest =
      zio.aws.apigatewaymanagementapi.model.GetConnectionRequest(connectionId)
    def connectionId: __string
    def getConnectionId: ZIO[Any, Nothing, __string] = ZIO.succeed(connectionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
  ) extends zio.aws.apigatewaymanagementapi.model.GetConnectionRequest.ReadOnly {
    override val connectionId: __string = impl.connectionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.GetConnectionRequest
  ): zio.aws.apigatewaymanagementapi.model.GetConnectionRequest.ReadOnly =
    new Wrapper(impl)
}
